<?php

namespace Drupal\codes_pool\Form;

use Drupal\codes_pool\Entity\CodeCollection;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Provides a form for importing codes.
 *
 * @internal
 */
class CodesImportForm extends ConfirmFormBase {

  /**
   * Collection.
   *
   * @var \Drupal\codes_pool\Entity\CodeCollection
   */
  protected $collection;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'codes_pool_codes_import_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('entity.codes_pool_collection.collection');
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to import codes');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, CodeCollection $codes_pool_collection = NULL) {
    $form = parent::buildForm($form, $form_state);
    $this->collection = $codes_pool_collection;
    $form['actions'] = ['#type' => 'actions'];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Import'),
      '#button_type' => 'primary',
    ];
    return $form;

  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $source = $this->collection->getSourcePlugin();
    if ($source->persistCodes()) {
      // @todo: add event to react to this case.
      $source->import();

      // @todo: Check if source has changed on update, if so,
      // delete all non-dispensed and insert new codes.
      // @todo: add event to react to this case.
      $this->messenger()->addMessage($this->t('Imported codes successfully.'));
      $form_state->setRedirect('entity.codes_pool_collection.collection');
    }
    else {
      $this->messenger()->addError($this->t('There is no codes to import.'));
    }

  }

}
